@@ -177,7 +177,9 @@ class Recipe(zc.recipe.egg.Eggs):
 
         # Write server script
         gae_server = os.path.join(gae, 'dev_appserver.py')
-        self.write_server_script(self.name, gae_server, sys_path)
+        self.write_server_script(self.options.get('server-script', self.name),  
+                                 gae_server,
+                                 sys_path)
 
         # Write app configuration script
         gae_config = os.path.join(gae, 'appcfg.py')
