@@ -20,6 +20,6 @@ setup(
     package_dir={'':'src'},
     namespace_packages=['foo'],
     zip_safe=False,
-    install_requires=['setuptools'],
+    install_requires=['setuptools', 'bazpkg'],
     entry_points="",
 )
